## START: Set by rpmautospec
## (rpmautospec version 0.3.0)
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global _description %{expand:
Read / write access to some common neuroimaging file formats

This package provides read +/- write access to some common medical and
neuroimaging file formats, including: ANALYZE (plain, SPM99, SPM2 and
later), GIFTI, NIfTI1, NIfTI2, MINC1, MINC2, MGH and ECAT as well as Philips
PAR/REC. We can read and write Freesurfer geometry, and read Freesurfer
morphometry and annotation files. There is some very limited support for DICOM.
NiBabel is the successor of PyNIfTI.

The various image format classes give full or selective access to header (meta)
information and access to the image data is made available via NumPy arrays.
}

Name:           python-nibabel
Version:        5.0.0
Release:        %autorelease
Summary:        Python package to access a cacophony of neuro-imaging file formats

License:        MIT and PDDL-1.0
URL:            http://nipy.org/nibabel/
Source0:        https://github.com/nipy/nibabel/archive/%{version}/nibabel-%{version}.tar.gz

# https://github.com/nipy/nibabel/pull/1194
Patch0:         https://github.com/nipy/nibabel/commit/60e1ca2c6b8bbe87bbc26258e8c40cc62c4bf07d.patch
Patch1:         https://github.com/nipy/nibabel/commit/870f106b9d13d7a6d00f71df0e997b5d4e048c66.patch

BuildRequires:  git-core

BuildArch:      noarch

%description %_description

%package -n python3-nibabel
Summary:        %{summary}

BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-httpserver
Recommends:     python3-scipy
Recommends:     python3-pydicom
# Bundles their own version of netcdf reader
# that is different from Scipy version
Provides:       bundled(python%{python3_version}dist(netcdf))

%description -n python3-nibabel %_description

%prep
# warning: don't use -S git/git_am here, or hatchling/hatch-vcs generates a wrong version
%autosetup -n nibabel-%{version} -p1

# delete shebangs from files that don't need it
find nibabel/cmdline/  -name "*.py" -execdir sed -i '/^#!python/ d' '{}' \;

# correct other shebangs
# upstream uses #!python as a shebang, correct it
find . -name "*.py" -execdir sed -i 's|^#!python|#!%{python3}|' '{}' \;

# delete .gitignore files
rm -fv nibabel/{tests/data/,}.gitignore


%generate_buildrequires
%pyproject_buildrequires -x dicom,minc2,spm

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files nibabel nisext

%check
# TestCifti2ImageAPI.test_filenames fails due to setuptools-bundled distutils'
# LooseVersion issue: https://github.com/pypa/distutils/issues/122
# This can be worked around by setting the environment variable to point
# to distutils from Python's standard library instead.
export SETUPTOOLS_USE_DISTUTILS=stdlib
# These three tests, completely unrelated to the two patches fail on application of patches.
# They're for deprecation etc., so ignore them for the moment
# Remember to include in the next release when patches are not used
%{pytest} -v -k "not test_unremoved_module and not test_unremoved_object and not test_unremoved_attr"

%files -n python3-nibabel -f %{pyproject_files}
%{_bindir}/parrec2nii
%{_bindir}/nib-conform
%{_bindir}/nib-convert
%{_bindir}/nib-diff
%{_bindir}/nib-dicomfs
%{_bindir}/nib-ls
%{_bindir}/nib-nifti-dx
%{_bindir}/nib-roi
%{_bindir}/nib-stats
%{_bindir}/nib-tck2trk
%{_bindir}/nib-trk2tck

%changelog
* Mon Feb 06 2023 Miro Hrončok <miro@hroncok.cz> 5.0.0-3
- Restore broken python provides
- Fixes: rhbz#2167445
- Fixes: rhbz#2167446
- Fixes: rhbz#2167447
- Fixes: rhbz#2167448
- Fixes: rhbz#2167449
- Fixes: rhbz#2167450

* Mon Feb 06 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> 5.0.0-2
- fix: backport patch to 5.x

* Thu Feb 02 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> 5.0.0-1
- feat: update to 5.0.0 (fixes rhbz#2094602)

* Thu Feb 02 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> 4.0.2-1
- feat: update to 4.0.2

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> 3.2.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> 3.2.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 14 2022 Python Maint <python-maint@redhat.com> 3.2.2-3
- Rebuilt for Python 3.11

* Mon Mar 07 2022 Karolina Surma <ksurma@redhat.com> 3.2.2-2
- Use distutils from Python's standard library to run tests

* Thu Feb 10 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> 3.2.2-1
- feat: update to 3.2.2 (fixes rhbz#2052120)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 3.2.1-3
- Rebuilt for Python 3.10

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Nov 28 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.2.1-1
- Update to latest bugfix release

* Sat Nov 28 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.2.0-1
- Update to latest release

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Jul 04 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.1.1-1
- Update to 3.1.1

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 3.1.0-2
- Rebuilt for Python 3.9

* Fri May 01 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.1.0-1
- Update to 3.1.0

* Sat Feb 01 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.0.1-1
- Update to new release
- Add pytest BR

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Fri Oct 25 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.5.1-1
- Update to 2.5.1

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 2.5.0-3
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 2.5.0-2
- Rebuilt for Python 3.8

* Sun Aug 04 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.5.0-1
- Update to latest release---fixes broken test

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Wed Jul 10 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.4.1-1
- Update to 2.4.1

* Sat Feb 16 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.3.3-1
- Update to 2.3.3

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Nov 07 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.3.1-1
- Update to latest upstream release
- Remove unneeded patch

* Mon Aug 13 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.3.0-3
- Drop python2 subpackage

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jun 22 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.3.0-1
- Update to 2.3.0
- No build since tests fail, issue filed: https://github.com/nipy/nibabel/issues/579

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.2.0-3
- Rebuilt for Python 3.7

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sun Nov 12 2017 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 2.2.0-1
- Update to 2.2.0

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Mar 11 2017 Igor Gnatenko <ignatenko@redhat.com> - 2.1.0-1
- Update to 2.1.0

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.0.2-4
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Mon Nov 23 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 2.0.2-1
- Update to 2.0.2
- unversioned bir to python3

* Sat Oct 31 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 2.0.1-1
- Initial package


